Application configuration - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Application configuration

Betty uses global application configuration for settings that do not impact your projects, such as the language you want to use Betty in, e.g. for the user interface and logs. This configuration can be managed through a configuration file.

The application configuration file is written in JSON and placed at `$HOME/.betty/configuration/app.json`. An example configuration:

    {
      "locale": "nl-NL"
    }

## All configuration options

- `locale` (optional): An IETF BCP 47 language tag. If no locale is specified, Betty defaults to US English (`en-US`).